@@ -749,10 +749,6 @@ class Tree(list):
     def from_list(L):
         if isinstance(L, str):
             return L
-        while len(L) == 1:
-            L = L[0]
-            if isinstance(L, str):
-                return L
         return Tree(L[0], [Tree.from_list(child) for child in L[1]])
 
     def __repr__(self):
